@@ -2,7 +2,7 @@ from datetime import timedelta
 from moksha.api.hub.producer import PollingProducer
 import zmq
 
-import fedmsg.json
+import fedmsg.encoding
 import logging
 
 log = logging.getLogger(__name__)
@@ -18,7 +18,7 @@ class HeartbeatProducer(PollingProducer):
         try:
             self.hub.send_message(
                 topic=self.topic,
-                message=fedmsg.json.dumps({'msg': "lub-dub"}),
+                message=fedmsg.encoding.dumps({'msg': "lub-dub"}),
             )
         except zmq.ZMQError, e:
             log.warn("Could not emit heartbeat: %r" % e)
